@@ -130,7 +130,9 @@ class TestUser:
                     return MockResponse(404,
                                         '{"success": false, "error": {"message": "TEST ERROR: Not create", "__type": "TEST ERROR: Not Create Error"}, "help": "http://test-data.humdata.org/api/3/action/help_show?name=user_create"}')
 
-                result = json.dumps(resultdict)
+                resultdictcopy = copy.deepcopy(resultdict)
+                resultdictcopy['state'] = datadict['state']
+                result = json.dumps(resultdictcopy)
                 if datadict['name'] == 'MyUser1':
                     return MockResponse(200,
                                         '{"success": true, "result": %s, "help": "http://test-data.humdata.org/api/3/action/help_show?name=user_create"}' % result)
@@ -289,6 +291,7 @@ Content-Transfer-Encoding: 7bit
         user.create_in_hdx()
         assert user['id'] == '9f3e9973-7dbe-4c65-8820-f48578e3ffea'
         assert user['capacity'] == 'admin'
+        assert user['state'] == 'active'
 
         data['name'] = 'MyUser2'
         user = User(data)
@@ -321,6 +324,7 @@ Content-Transfer-Encoding: 7bit
         assert user['id'] == '9f3e9973-7dbe-4c65-8820-f48578e3ffea'
         assert user['about'] == 'IMO'
         assert user['capacity'] == 'member'
+        assert user['state'] == 'active'
 
         user['id'] = 'NOTEXIST'
         with pytest.raises(HDXError):
@@ -337,6 +341,7 @@ Content-Transfer-Encoding: 7bit
         user.create_in_hdx()
         assert user['id'] == '9f3e9973-7dbe-4c65-8820-f48578e3ffea'
         assert user['about'] == 'Data Scientist'
+        assert user['state'] == 'active'
 
     def test_delete_from_hdx(self, configuration, post_delete):
         user = User.read_from_hdx('9f3e9973-7dbe-4c65-8820-f48578e3ffea')
@@ -369,20 +374,23 @@ Content-Transfer-Encoding: 7bit
         config = Configuration.read()
         config.setup_emailer(email_config_dict=TestUser.email_config_dict)
         User.email_users(users, TestUser.subject, TestUser.text_body, html_body=TestUser.html_body,
-                         sender=TestUser.sender, mail_options=TestUser.mail_options, rcpt_options=TestUser.rcpt_options)
+                         sender=TestUser.sender, cc=users, bcc=users, mail_options=TestUser.mail_options,
+                         rcpt_options=TestUser.rcpt_options)
         email = config.emailer()
         assert email.server.type == 'smtpssl'
         assert email.server.initargs == TestUser.smtp_initargs
         assert email.server.username == TestUser.username
         assert email.server.password == TestUser.password
         assert email.server.sender == TestUser.sender
-        assert email.server.recipients == ['xxx@yyy.com', 'aaa@bbb.com']
+        assert email.server.recipients == ['xxx@yyy.com', 'aaa@bbb.com', 'xxx@yyy.com', 'aaa@bbb.com', 'xxx@yyy.com',
+                                           'aaa@bbb.com']
         assert 'Content-Type: multipart/alternative;' in email.server.msg
         assert '''\
 MIME-Version: 1.0
 Subject: hello
 From: me@gmail.com
-To: xxx@yyy.com, aaa@bbb.com''' in email.server.msg
+To: xxx@yyy.com, aaa@bbb.com
+Cc: xxx@yyy.com, aaa@bbb.com''' in email.server.msg
         assert '''\
 Content-Type: text/plain; charset="us-ascii"
 MIME-Version: 1.0
